<?php
/*
Plugin Name: WooCommerce Ajax Drop Down Cart
Plugin URI: http://demo.netwakies.com/?item=nwajaxdropdowncart
Description: Sleek drop down cart widget for woocommerce
Version: 1.3.6
Author: Netwakies
Author URI: http://www.netwakies.com
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if(!defined('NW_AJAX_DROP_CART_PATH')) define( 'NW_AJAX_DROP_CART_PATH', plugin_dir_path(__FILE__) );

include_once(NW_AJAX_DROP_CART_PATH . "includes/class-nw-ajax-drop-cart.php");

/**
 * Initialization of 'NW_Ajax_Drop_Cart' class
 */
$_GLOBALS['nwajaxdropcart'] = new NW_Ajax_Drop_Cart();

if(!function_exists("woocommerce_mini_cart")) {
	function woocommerce_mini_cart( $args = array() ) {

	    $defaults = array( 'list_class' => '' );
	    $args = wp_parse_args( $args, $defaults );

	    woocommerce_get_template( 'cart/mini-cart.php', $args );

	}
}

function nw_get_template($file, $args) {

	extract($args);
	include_once(dirname(__FILE__)."/../".$file);

}

/**
 * activation/deactivation hooks
 *
 * multi-site ready
 */

register_activation_hook( __FILE__, 'nw_adcart_activate' );
register_deactivation_hook( __FILE__, 'nw_adcart_deactivate' );

function nw_adcart_activate($networkwide) {
    global $wpdb;

    if (function_exists('is_multisite') && is_multisite()) {
        // check if it is a network activation - if so, run the activation function for each blog id
        if ($networkwide) {
            $old_blog = $wpdb->blogid;
            // Get all blog ids
            $blogids = $wpdb->get_col("SELECT blog_id FROM $wpdb->blogs");
            foreach ($blogids as $blog_id) {
                switch_to_blog($blog_id);
                _nw_adcart_activate();
            }
            switch_to_blog($old_blog);
            return;
        }
    }
    _nw_adcart_activate();
}

function nw_adcart_deactivate($networkwide) {
    global $wpdb;

    if (function_exists('is_multisite') && is_multisite()) {
        // check if it is a network activation - if so, run the activation function for each blog id
        if ($networkwide) {
            $old_blog = $wpdb->blogid;
            // Get all blog ids
            $blogids = $wpdb->get_col("SELECT blog_id FROM $wpdb->blogs");
            foreach ($blogids as $blog_id) {
                switch_to_blog($blog_id);
                _nw_adcart_deactivate();
            }
            switch_to_blog($old_blog);
            return;
        }
    }
    _nw_adcart_deactivate();
}

function _nw_adcart_activate() {

	if(!get_option( "nwadcart_plugin_settings" )) {

		$settings = array(
			'nwadcart-skin' => 'custom',
			'nwadcart-position' => 'top',
			'nwadcart-subtotal' => 0,
			'nwadcart-border-radius' => 0,
			'nwadcart-item-name' => 'item',
			'nwadcart-item-name-plural' => 'items',
			'nwadcart-icon-color' => '000000',
			'nwadcart-text-color' => '000000',
			'nwadcart-link-color' => '000000',
			'nwadcart-button-text-color' => '000000',
			'nwadcart-background-color' => 'ffffff',
			'nwadcart-background-border-color' => 'e4e4e4',
			'nwadcart-icon-style' => '1',
			'nwadcart-custom-icon' => '',
			'nwadcart-use-custom-icon' => 0,
			'nwadcart-icon-position' => 'left',
			'nwadcart-drop-trigger' => 'click',
			'nwadcart-display-cart' => array('shop', 'category', 'product_tag', 'product', 'cart', 'checkout', 'account')
		);

		add_option( "nwadcart_plugin_settings", $settings );
	}

}

function _nw_adcart_deactivate() {

	if(get_option( "nwadcart_plugin_settings" )) {
		delete_option('nwadcart_plugin_settings');
	}

}

/**
 * new blog is added
 *
 * multi-site
 */
add_action( 'wpmu_new_blog', 'nw_adcart_new_blog', 10, 6);

function nw_adcart_new_blog($blog_id, $user_id, $domain, $path, $site_id, $meta ) {
    global $wpdb;

    if (is_plugin_active_for_network('woocommerce-nw-addcart/woocommerce-nw-ajax-drop-cart.php')) {
        $old_blog = $wpdb->blogid;
        switch_to_blog($blog_id);
        _nw_adcart_activate();
        switch_to_blog($old_blog);
    }
}

?>